valid_tools

Function valid_tools 

pub fn valid_tools() -> &'static [&'static str]
Returns the list of valid tool names derived from rules.json.

These are tools that have at least one rule specifically targeting them.